@@ -1,36 +1,34 @@
 import traceback
+from concurrent.futures import ThreadPoolExecutor
 
 from ..response import PageResponseObject
 from ..urllocation import UrlLocation
 from ..pages import RssPage
 from ..webtools import WebLogger
-from .defaulturlhandler import DefaultChannelHandler
+from .defaulturlhandler import DefaultRssChannelHandler, DefaultRssHtmlChannelHandler
 from .handlerhttppage import HttpPageHandler
 
 
-class YouTubeChannelHandler(DefaultChannelHandler):
+class YouTubeChannelHandler(DefaultRssHtmlChannelHandler):
     """
     Natively since we inherit RssPage, the contents should be RssPage
     """
 
-    def __init__(
-        self, url=None, contents=None, settings=None, request=None, url_builder=None
-    ):
-        self.html_url = None  # channel html page contains useful info
-        self.rss_url = None
+    def __init__(self, url=None, contents=None, request=None, url_builder=None):
         self.social_data = {}
+        self.user_name = None
+
+        if request:
+            request.cookies = {}
+            request.cookies["CONSENT"] = "YES+cb.20210328-17-p0.en+F+678"
 
         super().__init__(
             url,
             contents=contents,
-            settings=settings,
             request=request,
             url_builder=url_builder,
         )
 
-        if url:
-            self.code = self.input2code(url)
-
     def is_handled_by(self):
         if not self.url:
             return False
@@ -54,11 +52,11 @@ class YouTubeChannelHandler(DefaultChannelHandler):
         ):
             return True
 
-    def is_channel_name(self):
-        if not self.url:
+    def is_channel_name(self, url):
+        if not url:
             return False
 
-        short_url = UrlLocation(self.url).get_protocolless()
+        short_url = UrlLocation(url).get_protocolless()
 
         if (
             short_url.startswith("www.youtube.com/@")
@@ -81,6 +79,9 @@ class YouTubeChannelHandler(DefaultChannelHandler):
         return "https://www.youtube.com/feeds/videos.xml?channel_id={}".format(code)
 
     def get_feeds(self):
+        if not self.code:
+            return []
+
         feeds = super().get_feeds()
         if self.code:
             feeds.append(
@@ -96,9 +97,7 @@ class YouTubeChannelHandler(DefaultChannelHandler):
         if wh == -1:
             return None
 
-        if self.is_channel_name():
-            return self.input2code_handle(url)
-        if url.find("www.youtube.com/user") >= 0:
+        if self.is_channel_name(url):
             return self.input2code_handle(url)
         if url.find("/channel/") >= 0:
             return self.input2code_channel(url)
@@ -106,7 +105,42 @@ class YouTubeChannelHandler(DefaultChannelHandler):
             return self.input2code_feeds(url)
 
     def input2code_handle(self, url):
-        raise IOError("Not supported")
+        page_handler = self.get_page_url(url)
+        response = page_handler.get_response()
+        if not response:
+            return
+
+        props = page_handler.get_properties()
+        if not props:
+            return
+
+        if "feeds" in props:
+            if len(props["feeds"]) > 0:
+                feed = props["feeds"][0]
+                return self.input2code(feed)
+
+    def intpu2handlename(self, url):
+        wh = url.find("?")
+        if wh >= 0:
+            url = url[:wh]
+
+        wh1 = url.find("youtube.com/user")
+        if wh1 >= 0:
+            start = wh1 + len("youtube.com/user") + 1
+            wh2 = url.find("/", start+1)
+            if wh2 == -1:
+                return url[start-1:]
+            else:
+                return url[start-1:wh2]
+
+        wh1 = url.find("youtube.com/@")
+        if wh1 >= 0:
+            start = wh1 + len("youtube.com/@") + 1
+            wh2 = url.find("/", start + 1)
+            if wh2 == -1:
+                return url[start-1:]
+            else:
+                return url[start-1:wh2]
 
     def input2code_channel(self, url):
         wh = url.rfind("/")
@@ -120,14 +154,6 @@ class YouTubeChannelHandler(DefaultChannelHandler):
     def get_channel_code(self):
         return self.code
 
-    def get_channel_name(self):
-        url = self.get_rss_url()
-        if url:
-            return url.get_title()
-
-    def get_channel_url(self):
-        return self.code2url(self.code)
-
     def get_channel_url(self):
         if self.code:
             return self.code2url(self.code)
@@ -135,7 +161,6 @@ class YouTubeChannelHandler(DefaultChannelHandler):
     def get_contents(self):
         """
         We obtain information about channel.
-        We cannot use HTML page to obtain thumbnail - as web page asks to log in to view this
         """
         if self.dead:
             return
@@ -150,46 +175,19 @@ class YouTubeChannelHandler(DefaultChannelHandler):
         if response:
             return self.response.get_text()
 
-    def get_response(self):
+    def get_html_url(self):
+        #print("get_html_url")
+        if self.html_url:
+            return self.html_url
 
-        if self.response:
-            return self.response
-
-        if self.dead:
+        self.html_url = self.get_page_url(self.get_channel_url())
+        if not self.html_url:
             return
 
-        rss_url = self.get_rss_url()
-        if rss_url:
-            self.response = rss_url.get_response()
+        self.html_url.get_response()
 
-        if (
-            not self.response
-            or self.response.status_code == PageResponseObject.STATUS_CODE_ERROR
-        ):
-            self.dead = True
-
-        if self.response:
-            self.contents = self.response.get_text()
-            return self.response
-
-    def get_rss_url(self):
-        if self.rss_url:
-            return self.rss_url
-
-        feeds = self.get_feeds()
-        if not feeds or len(feeds) == 0:
-            WebLogger.error(
-                "Url:{} Cannot read YouTube channel feed URL".format(self.url)
-            )
-            return
-
-        feed = feeds[0]
-        if not feed:
-            return
-
-        self.rss_url = self.get_page_url(feed)
-        self.rss_url.get_response()
-        return self.rss_url
+        #print("get_html_url DONE")
+        return self.html_url
 
     def get_streams(self):
         if self.rss_url:
@@ -203,68 +201,6 @@ class YouTubeChannelHandler(DefaultChannelHandler):
 
         return self.streams
 
-    def get_html_url(self):
-        if False:
-            # TODO disabled
-            crawler_name = self.settings.get("name")
-            self.html_url = self.get_page_url(self.url, crawler_name=crawler_name)
-            self.html_url.get_response()
-            return self.html_url
-
-    def get_entries(self):
-        rss_url = self.get_rss_url()
-        if rss_url:
-            return rss_url.get_entries()
-        else:
-            return []
-
-    def get_title(self):
-        rss_url = self.get_rss_url()
-        if rss_url:
-            return rss_url.get_title()
-        html_url = self.get_html_url()
-        if html_url:
-            return html_url.get_title()
-
-    def get_description(self):
-        rss_url = self.get_rss_url()
-        if rss_url:
-            return rss_url.get_description()
-        html_url = self.get_html_url()
-        if html_url:
-            return html_url.get_description()
-
-    def get_language(self):
-        rss_url = self.get_rss_url()
-        if rss_url:
-            return rss_url.get_language()
-
-    def get_thumbnail(self):
-        rss_url = self.get_rss_url()
-        if rss_url:
-            thumbnail = rss_url.get_thumbnail()
-            if thumbnail:
-                return thumbnail
-
-        html_url = self.get_html_url()
-        if html_url:
-            return html_url.get_thumbnail()
-
-    def get_author(self):
-        rss_url = self.get_rss_url()
-        if rss_url:
-            return rss_url.get_author()
-
-    def get_album(self):
-        rss_url = self.get_rss_url()
-        if rss_url:
-            return rss_url.get_album()
-
-    def get_tags(self):
-        rss_url = self.get_rss_url()
-        if rss_url:
-            return rss_url.get_tags()
-
     def get_canonical_url(self):
         if self.url.find("feeds") >= 0:
             return self.url
@@ -274,7 +210,7 @@ class YouTubeChannelHandler(DefaultChannelHandler):
     def get_json_data(self):
         entries = self.get_entries()
         for entry in entries:
-            u = self.url_builder(url=entry["link"], settings=self.settings)
+            u = self.get_page_url(entry["link"])
             u.get_response()
             h = u.get_handler()
             if h:
