@@ -10,11 +10,12 @@ class HandlerInterface(DefaultContentPage):
     this allows us to provide interface
     """
 
-    def __init__(
-        self, url=None, contents=None, settings=None, request=None, url_builder=None
-    ):
+    def __init__(self, url=None, contents=None, request=None, url_builder=None):
+        if request and not url:
+            url = request.url
+
         super().__init__(
-            url,
+            url=url,
             contents=contents,
         )
         self.h = None
@@ -22,7 +23,6 @@ class HandlerInterface(DefaultContentPage):
         self.streams = {}
         self.dead = None
         self.code = None  # social media handle, ID of channel, etc.
-        self.settings = settings
         self.request = request
         self.handler = None  # for example rss UrlHandler
         self.url_builder = url_builder
@@ -161,8 +161,10 @@ class HandlerInterface(DefaultContentPage):
 
         if thumbs_up is not None and thumbs_down is not None:
             all = thumbs_down + thumbs_up
-
-            return thumbs_up / all
+            if all != 0:
+                return thumbs_up / all
+            else:
+                return 0
 
     def get_upvote_diff(self):
         thumbs_up = self.get_thumbs_up()
