@@ -222,22 +222,15 @@ class RemoteServer(object):
         if not all_properties:
             return
 
-        properties = RemoteServer.read_properties_section("Properties", all_properties)
-
-        if not properties:
-            return
-
-        if "link" not in properties:
-            return
-
         response_data = RemoteServer.read_properties_section("Response", all_properties)
-
         if not response_data:
             return
 
-        streams = RemoteServer.read_properties_section("Streams", all_properties)
-
         response = json_to_response(response_data)
+        if not response:
+            return
+
+        streams = RemoteServer.read_properties_section("Streams", all_properties)
 
         if streams and "Text" in streams:
             response.text = streams["Text"]
@@ -245,13 +238,11 @@ class RemoteServer(object):
         if streams and "Binary" in streams:
             response.binary = streams["Binary"]
 
-        if len(streams) > 0:
+        if streams and len(streams) > 0:
             for item in streams:
                 if item != "Binary":
                     response.text = streams[item]
 
-        url = properties["link"]
-
         return response
 
     def encode(data):
