@@ -42,10 +42,10 @@ class MockRequestCounter(object):
 
 
 class MockUrl(object):
-    def __init__(self, url=None, settings=None, request=None, url_builder=None):
+    def __init__(self, url=None, request=None, url_builder=None):
         self.url = url
-        self.settings = settings
         self.request = request
+        self.response = None
         self.url_builder = url_builder
 
     def get_init_settings(self):
@@ -64,16 +64,23 @@ class MockUrl(object):
         pass
 
     def get_contents(self):
-        return ""
+        response = self.get_response()
+        return response.get_text()
 
     def get_response(self):
+        if self.response:
+            return self.response
+
         headers = {}
         timeout_s = 20
         self.response = TestResponseObject(self.url, headers, timeout_s)
+
+        MockRequestCounter.requested(self.url, crawler_data=self.request)
+
         return self.response
 
     def get_streams(self):
-        pass
+        return []
 
     def ping(self, timeout_s=20, user_agent=None):
         return True
@@ -108,6 +115,9 @@ class MockUrl(object):
     def get_status_code(self):
         return 200
 
+    def get_properties(self):
+        return {}
+
 
 class MockCrawler(CrawlerInterface):
 
